from django.apps import AppConfig


class AmiqusAppConfig(AppConfig):
    """AppConfig for Django-Amiqus."""

    name = "amiqus"
    verbose_name = "Amiqus"
    default_auto_field = "django.db.models.AutoField"
