# Generated by Django 4.1.7 on 2023-03-31 12:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("amiqus", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="record",
            name="perform_url",
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name="record",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    ("pending", "Pending"),
                    ("started", "Started"),
                    ("complete", "Complete"),
                    ("incomplete", "Incomplete"),
                    ("waiting", "Waiting"),
                    ("failed", "Failed"),
                    ("empty", "Empty"),
                    ("amendments", "Amendments"),
                    ("paused", "Paused"),
                    ("reviewed", "Reviewed"),
                    ("unknown", "Unknown"),
                ],
                db_index=True,
                help_text="The current status of the record / check (from API).",
                max_length=20,
                null=True,
            ),
        ),
    ]
