# Generated by Django 4.2.7 on 2023-11-15 12:04

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("amiqus", "0002_record_perform_url_alter_record_status"),
    ]

    operations = [
        migrations.AlterField(
            model_name="client",
            name="status",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Unknown"),
                    ("approved", "Approved"),
                    ("rejected", "Rejected"),
                    ("pending", "Needs review"),
                ],
                db_index=True,
                help_text="The current status of the Client (from API).",
                max_length=20,
                null=True,
            ),
        ),
    ]
