from __future__ import annotations

from dataclasses import dataclass


@dataclass
class AmiqusCountry:
    name: str
    alpha3: str
    region: str
    subregion: str
    supported_identity_report: bool


COUNTRY_DATA_LIST = [
    {
        "name": "Afghanistan",
        "alpha3": "AFG",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Albania",
        "alpha3": "ALB",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Algeria",
        "alpha3": "DZA",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "American Samoa",
        "alpha3": "ASM",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Andorra",
        "alpha3": "AND",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Angola",
        "alpha3": "AGO",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Anguilla",
        "alpha3": "AIA",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Antarctica",
        "alpha3": "ATA",
        "region": "",
        "subregion": "",
        "supported_identity_report": False,
    },
    {
        "name": "Antigua and Barbuda",
        "alpha3": "ATG",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Argentina",
        "alpha3": "ARG",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Armenia",
        "alpha3": "ARM",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Aruba",
        "alpha3": "ABW",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Australia",
        "alpha3": "AUS",
        "region": "Oceania",
        "subregion": "Australia and New Zealand",
        "supported_identity_report": True,
    },
    {
        "name": "Austria",
        "alpha3": "AUT",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Azerbaijan",
        "alpha3": "AZE",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Bahamas",
        "alpha3": "BHS",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Bahrain",
        "alpha3": "BHR",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Bangladesh",
        "alpha3": "BGD",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Barbados",
        "alpha3": "BRB",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Belarus",
        "alpha3": "BLR",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Belgium",
        "alpha3": "BEL",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Belize",
        "alpha3": "BLZ",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Benin",
        "alpha3": "BEN",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Bermuda",
        "alpha3": "BMU",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": True,
    },
    {
        "name": "Bhutan",
        "alpha3": "BTN",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Bolivia (Plurinational State of)",
        "alpha3": "BOL",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "Bonaire, Sint Eustatius and Saba",
        "alpha3": "BES",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Bosnia and Herzegovina",
        "alpha3": "BIH",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Botswana",
        "alpha3": "BWA",
        "region": "Africa",
        "subregion": "Southern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Bouvet Island",
        "alpha3": "BVT",
        "region": "",
        "subregion": "",
        "supported_identity_report": False,
    },
    {
        "name": "Brazil",
        "alpha3": "BRA",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "British Indian Ocean Territory",
        "alpha3": "IOT",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Brunei Darussalam",
        "alpha3": "BRN",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Bulgaria",
        "alpha3": "BGR",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Burkina Faso",
        "alpha3": "BFA",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Burundi",
        "alpha3": "BDI",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Cabo Verde",
        "alpha3": "CPV",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Cambodia",
        "alpha3": "KHM",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Cameroon",
        "alpha3": "CMR",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Canada",
        "alpha3": "CAN",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": True,
    },
    {
        "name": "Cayman Islands",
        "alpha3": "CYM",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Central African Republic",
        "alpha3": "CAF",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Chad",
        "alpha3": "TCD",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Chile",
        "alpha3": "CHL",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "China",
        "alpha3": "CHN",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Christmas Island",
        "alpha3": "CXR",
        "region": "Oceania",
        "subregion": "Australia and New Zealand",
        "supported_identity_report": False,
    },
    {
        "name": "Cocos (Keeling) Islands",
        "alpha3": "CCK",
        "region": "Oceania",
        "subregion": "Australia and New Zealand",
        "supported_identity_report": False,
    },
    {
        "name": "Colombia",
        "alpha3": "COL",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Comoros",
        "alpha3": "COM",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Congo",
        "alpha3": "COG",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Congo (Democratic Republic of the)",
        "alpha3": "COD",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Cook Islands",
        "alpha3": "COK",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": True,
    },
    {
        "name": "Costa Rica",
        "alpha3": "CRI",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Croatia",
        "alpha3": "HRV",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Cuba",
        "alpha3": "CUB",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Curaçao",
        "alpha3": "CUW",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Cyprus",
        "alpha3": "CYP",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Czech Republic",
        "alpha3": "CZE",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Côte d'Ivoire",
        "alpha3": "CIV",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Denmark",
        "alpha3": "DNK",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Djibouti",
        "alpha3": "DJI",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Dominica",
        "alpha3": "DMA",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Dominican Republic",
        "alpha3": "DOM",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Ecuador",
        "alpha3": "ECU",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Egypt",
        "alpha3": "EGY",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "El Salvador",
        "alpha3": "SLV",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Equatorial Guinea",
        "alpha3": "GNQ",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Eritrea",
        "alpha3": "ERI",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Estonia",
        "alpha3": "EST",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Ethiopia",
        "alpha3": "ETH",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Falkland Islands (Malvinas)",
        "alpha3": "FLK",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "Faroe Islands",
        "alpha3": "FRO",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Fiji",
        "alpha3": "FJI",
        "region": "Oceania",
        "subregion": "Melanesia",
        "supported_identity_report": True,
    },
    {
        "name": "Finland",
        "alpha3": "FIN",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "France",
        "alpha3": "FRA",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "French Guiana",
        "alpha3": "GUF",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "French Polynesia",
        "alpha3": "PYF",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "French Southern Territories",
        "alpha3": "ATF",
        "region": "",
        "subregion": "",
        "supported_identity_report": False,
    },
    {
        "name": "Gabon",
        "alpha3": "GAB",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Gambia",
        "alpha3": "GMB",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Georgia",
        "alpha3": "GEO",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Germany",
        "alpha3": "DEU",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Ghana",
        "alpha3": "GHA",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Gibraltar",
        "alpha3": "GIB",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Greece",
        "alpha3": "GRC",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Greenland",
        "alpha3": "GRL",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": False,
    },
    {
        "name": "Grenada",
        "alpha3": "GRD",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Guadeloupe",
        "alpha3": "GLP",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Guam",
        "alpha3": "GUM",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Guatemala",
        "alpha3": "GTM",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Guernsey",
        "alpha3": "GGY",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Guinea",
        "alpha3": "GIN",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Guinea-Bissau",
        "alpha3": "GNB",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Guyana",
        "alpha3": "GUY",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "Haiti",
        "alpha3": "HTI",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Heard Island and McDonald Islands",
        "alpha3": "HMD",
        "region": "",
        "subregion": "",
        "supported_identity_report": False,
    },
    {
        "name": "Holy See",
        "alpha3": "VAT",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": False,
    },
    {
        "name": "Honduras",
        "alpha3": "HND",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Hong Kong",
        "alpha3": "HKG",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Hungary",
        "alpha3": "HUN",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Iceland",
        "alpha3": "ISL",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "India",
        "alpha3": "IND",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Indonesia",
        "alpha3": "IDN",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Iran (Islamic Republic of)",
        "alpha3": "IRN",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Iraq",
        "alpha3": "IRQ",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Ireland",
        "alpha3": "IRL",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Isle of Man",
        "alpha3": "IMN",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Israel",
        "alpha3": "ISR",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Italy",
        "alpha3": "ITA",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Jamaica",
        "alpha3": "JAM",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Japan",
        "alpha3": "JPN",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Jersey",
        "alpha3": "JEY",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Jordan",
        "alpha3": "JOR",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Kazakhstan",
        "alpha3": "KAZ",
        "region": "Asia",
        "subregion": "Central Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Kenya",
        "alpha3": "KEN",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Kiribati",
        "alpha3": "KIR",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Korea (Democratic People's Republic of)",
        "alpha3": "PRK",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Korea (Republic of)",
        "alpha3": "KOR",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Kuwait",
        "alpha3": "KWT",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Kyrgyzstan",
        "alpha3": "KGZ",
        "region": "Asia",
        "subregion": "Central Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Lao People's Democratic Republic",
        "alpha3": "LAO",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Latvia",
        "alpha3": "LVA",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Lebanon",
        "alpha3": "LBN",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Lesotho",
        "alpha3": "LSO",
        "region": "Africa",
        "subregion": "Southern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Liberia",
        "alpha3": "LBR",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Libya",
        "alpha3": "LBY",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Liechtenstein",
        "alpha3": "LIE",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Lithuania",
        "alpha3": "LTU",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Luxembourg",
        "alpha3": "LUX",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Macao",
        "alpha3": "MAC",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Madagascar",
        "alpha3": "MDG",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Malawi",
        "alpha3": "MWI",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Malaysia",
        "alpha3": "MYS",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Maldives",
        "alpha3": "MDV",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Mali",
        "alpha3": "MLI",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Malta",
        "alpha3": "MLT",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Marshall Islands",
        "alpha3": "MHL",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Martinique",
        "alpha3": "MTQ",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Mauritania",
        "alpha3": "MRT",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Mauritius",
        "alpha3": "MUS",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Mayotte",
        "alpha3": "MYT",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Mexico",
        "alpha3": "MEX",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Micronesia (Federated States of)",
        "alpha3": "FSM",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Moldova (Republic of)",
        "alpha3": "MDA",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Monaco",
        "alpha3": "MCO",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Mongolia",
        "alpha3": "MNG",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Montenegro",
        "alpha3": "MNE",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Montserrat",
        "alpha3": "MSR",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Morocco",
        "alpha3": "MAR",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Mozambique",
        "alpha3": "MOZ",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Myanmar",
        "alpha3": "MMR",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Namibia",
        "alpha3": "NAM",
        "region": "Africa",
        "subregion": "Southern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Nauru",
        "alpha3": "NRU",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Nepal",
        "alpha3": "NPL",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Netherlands",
        "alpha3": "NLD",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "New Caledonia",
        "alpha3": "NCL",
        "region": "Oceania",
        "subregion": "Melanesia",
        "supported_identity_report": False,
    },
    {
        "name": "New Zealand",
        "alpha3": "NZL",
        "region": "Oceania",
        "subregion": "Australia and New Zealand",
        "supported_identity_report": True,
    },
    {
        "name": "Nicaragua",
        "alpha3": "NIC",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Niger",
        "alpha3": "NER",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Nigeria",
        "alpha3": "NGA",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Niue",
        "alpha3": "NIU",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Norfolk Island",
        "alpha3": "NFK",
        "region": "Oceania",
        "subregion": "Australia and New Zealand",
        "supported_identity_report": True,
    },
    {
        "name": "North Macedonia",
        "alpha3": "MKD",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": False,
    },
    {
        "name": "Northern Mariana Islands",
        "alpha3": "MNP",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Norway",
        "alpha3": "NOR",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Oman",
        "alpha3": "OMN",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Pakistan",
        "alpha3": "PAK",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Palau",
        "alpha3": "PLW",
        "region": "Oceania",
        "subregion": "Micronesia",
        "supported_identity_report": False,
    },
    {
        "name": "Palestine, State of",
        "alpha3": "PSE",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Panama",
        "alpha3": "PAN",
        "region": "Americas",
        "subregion": "Central America",
        "supported_identity_report": True,
    },
    {
        "name": "Papua New Guinea",
        "alpha3": "PNG",
        "region": "Oceania",
        "subregion": "Melanesia",
        "supported_identity_report": False,
    },
    {
        "name": "Paraguay",
        "alpha3": "PRY",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Peru",
        "alpha3": "PER",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Philippines",
        "alpha3": "PHL",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Pitcairn",
        "alpha3": "PCN",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Poland",
        "alpha3": "POL",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Portugal",
        "alpha3": "PRT",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Puerto Rico",
        "alpha3": "PRI",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Qatar",
        "alpha3": "QAT",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Romania",
        "alpha3": "ROU",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Russian Federation",
        "alpha3": "RUS",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Rwanda",
        "alpha3": "RWA",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Réunion",
        "alpha3": "REU",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Saint Barthélemy",
        "alpha3": "BLM",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Saint Helena, Ascension and Tristan da Cunha",
        "alpha3": "SHN",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Saint Kitts and Nevis",
        "alpha3": "KNA",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Saint Lucia",
        "alpha3": "LCA",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Saint Martin (French part)",
        "alpha3": "MAF",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Saint Pierre and Miquelon",
        "alpha3": "SPM",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": False,
    },
    {
        "name": "Saint Vincent and the Grenadines",
        "alpha3": "VCT",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Samoa",
        "alpha3": "WSM",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": True,
    },
    {
        "name": "San Marino",
        "alpha3": "SMR",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": False,
    },
    {
        "name": "Sao Tome and Principe",
        "alpha3": "STP",
        "region": "Africa",
        "subregion": "Middle Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Saudi Arabia",
        "alpha3": "SAU",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Senegal",
        "alpha3": "SEN",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Serbia",
        "alpha3": "SRB",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Seychelles",
        "alpha3": "SYC",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Sierra Leone",
        "alpha3": "SLE",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Singapore",
        "alpha3": "SGP",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Sint Maarten (Dutch part)",
        "alpha3": "SXM",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Slovakia",
        "alpha3": "SVK",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Slovenia",
        "alpha3": "SVN",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Solomon Islands",
        "alpha3": "SLB",
        "region": "Oceania",
        "subregion": "Melanesia",
        "supported_identity_report": False,
    },
    {
        "name": "Somalia",
        "alpha3": "SOM",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "South Africa",
        "alpha3": "ZAF",
        "region": "Africa",
        "subregion": "Southern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "South Georgia and the South Sandwich Islands",
        "alpha3": "SGS",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "South Sudan",
        "alpha3": "SSD",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Spain",
        "alpha3": "ESP",
        "region": "Europe",
        "subregion": "Southern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Sri Lanka",
        "alpha3": "LKA",
        "region": "Asia",
        "subregion": "Southern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Sudan",
        "alpha3": "SDN",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Suriname",
        "alpha3": "SUR",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "Svalbard and Jan Mayen",
        "alpha3": "SJM",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": False,
    },
    {
        "name": "Sweden",
        "alpha3": "SWE",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Switzerland",
        "alpha3": "CHE",
        "region": "Europe",
        "subregion": "Western Europe",
        "supported_identity_report": True,
    },
    {
        "name": "Syrian Arab Republic",
        "alpha3": "SYR",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Taiwan, Province of China",
        "alpha3": "TWN",
        "region": "Asia",
        "subregion": "Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Tajikistan",
        "alpha3": "TJK",
        "region": "Asia",
        "subregion": "Central Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Tanzania, United Republic of",
        "alpha3": "TZA",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Thailand",
        "alpha3": "THA",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Timor-Leste",
        "alpha3": "TLS",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Togo",
        "alpha3": "TGO",
        "region": "Africa",
        "subregion": "Western Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Tokelau",
        "alpha3": "TKL",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Tonga",
        "alpha3": "TON",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Trinidad and Tobago",
        "alpha3": "TTO",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Tunisia",
        "alpha3": "TUN",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Turkey",
        "alpha3": "TUR",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Turkmenistan",
        "alpha3": "TKM",
        "region": "Asia",
        "subregion": "Central Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Turks and Caicos Islands",
        "alpha3": "TCA",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Tuvalu",
        "alpha3": "TUV",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": True,
    },
    {
        "name": "Uganda",
        "alpha3": "UGA",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Ukraine",
        "alpha3": "UKR",
        "region": "Europe",
        "subregion": "Eastern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "United Arab Emirates",
        "alpha3": "ARE",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": True,
    },
    {
        "name": "United Kingdom of Great Britain and Northern Ireland",
        "alpha3": "GBR",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
    {
        "name": "United States Minor Outlying Islands",
        "alpha3": "UMI",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": False,
    },
    {
        "name": "United States of America",
        "alpha3": "USA",
        "region": "Americas",
        "subregion": "Northern America",
        "supported_identity_report": True,
    },
    {
        "name": "Uruguay",
        "alpha3": "URY",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": False,
    },
    {
        "name": "Uzbekistan",
        "alpha3": "UZB",
        "region": "Asia",
        "subregion": "Central Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Vanuatu",
        "alpha3": "VUT",
        "region": "Oceania",
        "subregion": "Melanesia",
        "supported_identity_report": True,
    },
    {
        "name": "Venezuela (Bolivarian Republic of)",
        "alpha3": "VEN",
        "region": "Americas",
        "subregion": "South America",
        "supported_identity_report": True,
    },
    {
        "name": "Viet Nam",
        "alpha3": "VNM",
        "region": "Asia",
        "subregion": "South-Eastern Asia",
        "supported_identity_report": True,
    },
    {
        "name": "Virgin Islands (British)",
        "alpha3": "VGB",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": True,
    },
    {
        "name": "Virgin Islands (U.S.)",
        "alpha3": "VIR",
        "region": "Americas",
        "subregion": "Caribbean",
        "supported_identity_report": False,
    },
    {
        "name": "Wallis and Futuna",
        "alpha3": "WLF",
        "region": "Oceania",
        "subregion": "Polynesia",
        "supported_identity_report": False,
    },
    {
        "name": "Western Sahara",
        "alpha3": "ESH",
        "region": "Africa",
        "subregion": "Northern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Yemen",
        "alpha3": "YEM",
        "region": "Asia",
        "subregion": "Western Asia",
        "supported_identity_report": False,
    },
    {
        "name": "Zambia",
        "alpha3": "ZMB",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "Zimbabwe",
        "alpha3": "ZWE",
        "region": "Africa",
        "subregion": "Eastern Africa",
        "supported_identity_report": True,
    },
    {
        "name": "eSwatini",
        "alpha3": "SWZ",
        "region": "Africa",
        "subregion": "Southern Africa",
        "supported_identity_report": False,
    },
    {
        "name": "Åland Islands",
        "alpha3": "ALA",
        "region": "Europe",
        "subregion": "Northern Europe",
        "supported_identity_report": True,
    },
]


# raw data converted to a dict for faster lookup
COUNTRY_DATA_DICT = {c["alpha3"]: c for c in COUNTRY_DATA_LIST}


def get_country(alpha3: str) -> AmiqusCountry | None:
    if country_data := COUNTRY_DATA_DICT.get(alpha3):
        return AmiqusCountry(**country_data)  # type: ignore
    return None
